/*****************************************************************************
 *
 * $Id$
 *
 * Copyright (C) 2009 - 2012  Richard Hacker <lerich@gmx.net>
 *                            Florian Pose <fp@igh-essen.com>
 *
 * This file is part of the PdCom library.
 *
 * The PdCom library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * The PdCom library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with the PdCom Library. If not, see <http://www.gnu.org/licenses/>.
 *
 ****************************************************************************/

#ifndef PDCOM_H
#define PDCOM_H

#include "pdcom/Process.h"
#include "pdcom/Variable.h"
#include "pdcom/Subscriber.h"
#include "pdcom/Exception.h"

// Set for development code; in this case, the variables PDCOM_*
// do not evaluate correctly
#define PDCOM_DEVEL 0

#define PDCOM_MAJOR 3
#define PDCOM_MINOR 0
#define PDCOM_RELEASE 11

#define PDCOM_VERSION(A, B, C) (((A) << 16) + ((B) << 8) + (C))
#define PDCOM_VERSION_CODE \
        PDCOM_VERSION(PDCOM_MAJOR, PDCOM_MINOR, PDCOM_RELEASE)

/** \mainpage
 *
 * \section intro Introduction.
 *
 * The <a href="http://etherlab.org/en/pdcom">PdCom library</a> provides a
 * flexible C++ API for non-realtime exchange of process data and is part of
 * the <a href="http://etherlab.org/en">EtherLab project</a>. It is designed to
 * be independent of any communication protocols and channels, and shall be
 * usable under several operating systems and platforms. I. e. it has been
 * tested successfully under Linux and Windows.
 *
 * \section license License
 *
 * The PdCom library is released under the terms and conditions of the <a
 * href="http://www.gnu.org/licenses/lgpl.html">GNU Lesser General Public
 * License (LGPL)</a>, version 3 or (at your option) any later version.
 *
 * \section protocols Implemented communication protocols
 *
 * The library provides an abstraction layer for process data communication
 * protocols together with implementations for these protocols. The protocols
 * currently implemented are:
 *
 * - The MSR protocol from Ingenieurgemeinschaft IgH (http://etherlab.org).
 *
 * Other protocols can be easily added.
 *
 * \section start Getting started
 *
 * The basic approach to take it into operation is to subclass PdCom::Process
 * to implement the communication channel and to subclass
 * PdCom::VariableSubscriber to receive the process data. Have a look at the
 * class documentations to get more information. An example is located in the
 * example directory.
 *
 * \section further Further information
 *
 * There is a Qt-based widget library named <a
 * href="http://etherlab.org/en/pdwidgets">QtPdWidgets</a>, providing process
 * data visualisation and control widgets, that is based on PdCom.
 */

#endif // PDCOM_H

/****************************************************************************/
